@@ -39,13 +39,8 @@ shopt -s extglob
 
 file=${2##*/}
 name=${file%.*}
+
 class=${name#Abstract}
-if [[ "$class" == "$name" ]]; then
-    abstract=
-else
-    abstract=Abstract
-fi
-class=${class#Striped}
 
 # Now we rip off the types.
 rem=${class##[A-Z]+([a-z])}
@@ -573,6 +568,7 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 "#define ARRAY_LIST ${TYPE_CAP[$k]}ArrayList\n"\
 "#define IMMUTABLE_LIST ${TYPE_CAP[$k]}ImmutableList\n"\
 "#define BIG_ARRAY_BIG_LIST ${TYPE_CAP[$k]}BigArrayBigList\n"\
+"#define MAPPED_BIG_LIST ${TYPE_CAP[$k]}MappedBigList\n"\
 "#define ARRAY_FRONT_CODED_LIST ${TYPE_CAP[$k]}ArrayFrontCodedList\n"\
 "#define ARRAY_FRONT_CODED_BIG_LIST ${TYPE_CAP[$k]}ArrayFrontCodedBigList\n"\
 "#define HEAP_PRIORITY_QUEUE ${TYPE_CAP2[$k]}HeapPriorityQueue\n"\
@@ -584,6 +580,7 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 "#define ARRAY_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayPriorityQueue\n"\
 "#define ARRAY_INDIRECT_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectPriorityQueue\n"\
 "#define ARRAY_INDIRECT_DOUBLE_PRIORITY_QUEUE ${TYPE_CAP2[$k]}ArrayIndirectDoublePriorityQueue\n"\
+"#define KEY_BUFFER ${TYPE_CAP[$k]}Buffer\n"\
 \
 \
 "/* Synchronized wrappers */\n"\
@@ -616,6 +613,7 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 \
 "#define KEY_READER_WRAPPER ${TYPE_CAP[$k]}ReaderWrapper\n"\
 "#define KEY_DATA_INPUT_WRAPPER ${TYPE_CAP[$k]}DataInputWrapper\n"\
+"#define KEY_DATA_NIO_INPUT_WRAPPER ${TYPE_CAP[$k]}DataNioInputWrapper\n"\
 \
 \
 "/* Methods (keys) */\n"\
@@ -632,6 +630,7 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 "#define FIRST_KEY first${TYPE_STD[$k]}Key\n"\
 "#define LAST_KEY last${TYPE_STD[$k]}Key\n"\
 "#define GET_KEY get${TYPE_STD[$k]}\n"\
+"#define AS_KEY_BUFFER as${TYPE_STD[$k]}Buffer\n"\
 "#define PAIR_LEFT left${TYPE_STD[$k]}\n"\
 "#define PAIR_FIRST first${TYPE_STD[$k]}\n"\
 "#define PAIR_KEY key${TYPE_STD[$k]}\n"\
@@ -665,9 +664,13 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 "#if KEYS_REFERENCE\n"\
 "#define MAP_TO_KEY map\n"\
 "#define MAP_TO_KEY_WIDENED map\n"\
+"#define RETURN_FALSE_IF_KEY_NULL(k) if (k == null) return false;\n"\
+"#define REQUIRE_KEY_NON_NULL(k) java.util.Objects.requireNonNull(k);\n"\
 "#else\n"\
 "#define MAP_TO_KEY mapTo${TYPE_CAP2[$k]}\n"\
 "#define MAP_TO_KEY_WIDENED mapTo${TYPE_CAP2[$wk]}\n"\
+"#define REQUIRE_KEY_NON_NULL(k)\n"\
+"#define RETURN_FALSE_IF_KEY_NULL(k)\n"\
 "#endif\n"\
 \
 \
@@ -687,6 +690,11 @@ $(if [[ "${CLASS[$k]}" != "" && "${CLASS[$v]}" != "" ]]; then\
 "#define PAIR_RIGHT right${TYPE_STD[$v]}\n"\
 "#define PAIR_SECOND second${TYPE_STD[$v]}\n"\
 "#define PAIR_VALUE value${TYPE_STD[$v]}\n"\
+"#if VALUES_REFERENCE\n"\
+"#define REQUIRE_VALUE_NON_NULL(v) java.util.Objects.requireNonNull(v);\n"\
+"#else\n"\
+"#define REQUIRE_VALUE_NON_NULL(v)\n"\
+"#endif\n"\
 \
 \
 "/* Methods (keys/values) */\n"\
